function Demand()
%Demand() GUI interface script for all bridges in the project
%   Kevin Mackie, 2002/01/27
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   Spawns appropriate functions for viewing PSDMs

clear all;
close all;
load Demand;

% computer type
comptype=computer;

% figure window and axes ----------------------------------------------
if strcmp(comptype,'PCWIN')==1,
a = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'Position',[10 210 655 510], ...
	'Tag','Fig1');
else
a = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'Position',[10 340 512 384], ...
	'Tag','Fig1');
end;

b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','PSDAPlot no_abut_1', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[296 230.5 80 30], ...
	'String','PSDA', ...
	'Tag','Pushbutton1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','PSDAPlot abut_1', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[296 192 80 30], ...
	'String','PSDA', ...
	'Tag','Pushbutton2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','PSDAPlot abut_2', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[296 153 80 30], ...
	'String','PSDA', ...
	'Tag','Pushbutton3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','PSDAPlot no_abut_3', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[296 114 80 30], ...
	'String','PSDA', ...
	'Tag','Pushbutton4');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','PSDAPlot ncee_abut', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[296 75 80 30], ...
	'String','PSDA', ...
	'Tag','Pushbutton5');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','PSDAPlot nsc_abut', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[296 36 80 30], ...
	'String','PSDA', ...
	'Tag','Pushbutton6');

% IDA push buttons
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','IDAPlot no_abut_1', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[400 230.5 80 30], ...
	'String','IDA', ...
	'Tag','Pushbutton7');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','IDAPlot abut_1', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[400 192 80 30], ...
	'String','IDA (N/A)', ...
	'Tag','Pushbutton8');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','IDAPlot abut_2', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[400 153 80 30], ...
	'String','IDA (N/A)', ...
	'Tag','Pushbutton9');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','IDAPlot no_abut_3', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[400 114 80 30], ...
	'String','IDA (N/A)', ...
	'Tag','Pushbutton10');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','IDAPlot ncee_abut', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[400 75 80 30], ...
	'String','IDA', ...
	'Tag','Pushbutton11');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','IDAPlot nsc_abut', ...
	'FontName','Times New Roman', ...
	'FontSize',12, ...
	'Position',[400 36 80 30], ...
	'String','IDA (N/A)', ...
	'Tag','Pushbutton12');
	
% Text fields.......................
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'FontSize',24, ...
	'Position',[27 302 458 73], ...
	'String','PEER 312 Seismic Demands for California Highway Bridges', ...
	'Style','text', ...
	'Tag','StaticText1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[112 275 309 15], ...
	'String','Select your Bridge Type and Analysis Method...', ...
	'Style','text', ...
	'Tag','StaticText2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[23 240.5 231 15], ...
	'String','Single column-single bent no abutments', ...
	'Style','text', ...
	'Tag','StaticText3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[23 202 231 15], ...
	'String','Single column-single bent with abutments', ...
	'Style','text', ...
	'Tag','StaticText4');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[23 163 231 15], ...
	'String','Single column-2 bent with abutments', ...
	'Style','text', ...
	'Tag','StaticText5');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[23 124 231 15], ...
	'String','Single column-3 bent no abutments', ...
	'Style','text', ...
	'Tag','StaticText6');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[23 85 231 15], ...
	'String','Single column/bent with abutments NCEE', ...
	'Style','text', ...
	'Tag','StaticText7');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[23 46 231 15], ...
	'String','Single column/bent with abutments NSC', ...
	'Style','text', ...
	'Tag','StaticText8');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'FontSize',8, ...
	'Position',[263 1 235 15], ...
	'String','Kevin Mackie, University of California Berkeley, 2002', ...
	'Style','text', ...
	'Tag','StaticText9');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[23 7 60 15], ...
	'String','Others', ...
	'Style','text', ...
	'Tag','StaticText10');

% pop-up menus
vals=['Bent combinations'];
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(20)', ...
	'FontSize',9, ...
	'Position',[90 7 150 15], ...
	'String',vals, ...
	'Style','popupmenu', ...
	'Tag','othermenu', ...
	'Value',1);
