function GeneratePlot()
%GeneratePlot(plottype) Plot updating function
%   Kevin Mackie, 2001/07/19
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   plottype - 0 for any PSDM plot type
%              1 for any IDA plot type
%
% Function called from GUI callbacks to generate plots from given
% pop up menu values in the plotting window

global XAX;
global YAX;
global TYP;
global GRP;
global FIT;
global SIG;
global MODEL;
global DEQ;
global SUMLOC;

global NVALS;
global IM_ARR;
global DM_ARR;
global RS_ARR;

plottype = MODEL;
			 
[T1,PData]=LoadMenu(SUMLOC,MODEL);

switch plottype

case 0,     % any of the plots in the Plot Type menu for PSDM's
   % go about obtaining the lists like from makeplot on unix
   switch TYP
   
   case 1,     % Parameter plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,TYP,GRP,PData{GRP},XAX,YAX);
	  PlotParameter(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT,SIG,DEQ);
	  
	  % Revert back to log-log space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',1);
   
   case 2,     % Seismicity plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,TYP,GRP,PData{GRP},XAX,YAX);
	  PlotSeismicity(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT,SIG);
	  
	  % Revert back to log-log space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',1);
   
   case 3,     % Bin Dependence plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX);
	  PlotSeismParam(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:));
	  
	  % Revert back to log-log space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',1);
	  % Revert back to linear fit in menu
      chng = findobj('Tag','PopupMenu4');
      set(chng,'Value',1);
	  FIT=1;
   
   case 4,     % M Dependence plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(2,2));
	  PlotResidual(grpy,bins,PData{GRP},NVALS(RS_ARR(2,2),:),NVALS(XAX,:),FIT);
	  
	  % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);
   
   case 5,     % R Dependence plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(3,2));
	  PlotResidual(grpy,bins,PData{GRP},NVALS(RS_ARR(3,2),:),NVALS(XAX,:),FIT);
   
      % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);
 
   case 6,     % Duration Dependence plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(1,2));
	  PlotResidual(grpy,bins,PData{GRP},NVALS(RS_ARR(1,2),:),NVALS(XAX,:),FIT);
	  
	  % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);
	  
   case 7,     % 3D IM vector plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,IM_ARR(length(IM_ARR)-8,2));
	  PlotVector(grpy,bins,PData{GRP},NVALS(YAX,:),'/Sd_T_2',NVALS(XAX,:));
	  
	  % Revert back to linear space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',2);
	  
   case 8,     % Structural demand hazard curve
      clear grpy;
	  [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(4,2),RS_ARR(5,2));
	  PlotSDHC(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT,SIG);
	  
	  % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);

   case 9,     % Demand fragility curve
      clear grpy;
	  [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX);
	  PlotFragility(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT);
	  
	  % Revert back to linear space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',2);
	  
   otherwise
      disp('Unknown plot type requested for PSDA in GeneratePlot.m');
   end;

case 1,     % any of the plots in the Plot Type menu for IDA's
   % go about obtaining the lists like from makeplot on unix
   switch TYP
   
   case 1,     % Parameter plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,TYP,GRP,PData{GRP},XAX,YAX);
	  PlotParameter(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT,SIG,DEQ);
	  
	  % Revert back to log-log space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',1);
   
   case 2,     % Seismicity plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,TYP,GRP,PData{GRP},XAX,YAX);
	  PlotSeismicity(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT,SIG);
	  
	  % Revert back to log-log space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',1);
   
   case 3,     % Typical IDA plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX);
	  PlotIDA(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:));
	  
	  % Revert back to linear space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',2);
	  % Revert back to linear space in menu
      chng = findobj('Tag','PopupMenu4');
      set(chng,'Value',1);
	  FIT=1;
   
   case 4,     % M Dependence plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(2,2));
	  PlotResidual(grpy,bins,PData{GRP},NVALS(RS_ARR(2,2),:),NVALS(XAX,:),FIT);
	  
	  % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);
   
   case 5,     % R Dependence plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(3,2));
	  PlotResidual(grpy,bins,PData{GRP},NVALS(RS_ARR(3,2),:),NVALS(XAX,:),FIT);
   
      % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);
 
   case 6,     % Duration Dependence plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(1,2));
	  PlotResidual(grpy,bins,PData{GRP},NVALS(RS_ARR(1,2),:),NVALS(XAX,:),FIT);
	  
	  % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);

   case 7,     % 3D IM vector plot
      clear grpy;
      [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,IM_ARR(length(IM_ARR)-8,2));
	  PlotVector(grpy,bins,PData{GRP},NVALS(YAX,:),'/Sd_T_2',NVALS(XAX,:));
	  
	  % Revert back to linear space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',2);

   case 8,     % Structural demand hazard curve
      clear grpy;
	  [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX,RS_ARR(4,2),RS_ARR(5,2));
	  PlotSDHC(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT,SIG);
	  
	  % Revert back to semilogy space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',4);
	  
   case 9,     % Demand fragility curve
      clear grpy;
	  [grpy,bins]=MakeMatrix(MODEL,1,GRP,PData{GRP},XAX,YAX);
	  PlotFragility(grpy,bins,PData{GRP},NVALS(XAX,:),NVALS(YAX,:),FIT);
	  
	  % Revert back to linear space in menu
      chng = findobj('Tag','PopupMenu3');
      set(chng,'Value',2);
	  
   otherwise
      disp('Unknown plot type requested for IDA in GeneratePlot.m');
   end;
   
otherwise
   disp('Unknown plot type requested in GeneratePlot.m');
end;
