function [T1,PData] = LoadMenu(bridgein,typer)
%T1=LoadMenu Load bridge specific menus
%   Kevin Mackie, 2002/01/26
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   bridgein name of bridge type to associate values and names
%   typer 0 for PSDA 1 for IDA
%
%   T1 array of menu values
%   PD array of data used to associate parameters for plotting

% first generate menu
if typer == 0,		% PSDA
switch bridgein
   case 'no_abut_1',
T1=['L/H      ';'Dc/Ds    ';'\rho_s,ln' ;'L        ';'weight   '; ...
    'ksoil    ';'fy       ';'f''c      ';'\rho_s,tr';'abut     '; ...
	'abut/no  ';'Dc/Ds5   ';'deck     ' ;'skew     '];
   case 'no_abut_2',
T1=['NYI      '];
   case 'no_abut_3',
T1=['L2       ';'L2/H2    ';'Dc2/Ds   ';'irregular'];
   case 'abut_1',
T1=['L/H      ';'Dc/Ds    ';'\rho_s,ln' ;'L        ';'weight   '; ...
    'ksoil    ';'fy       ';'f''c      ';'\rho_s,tr'; ...
	'Dc/Ds5   ';'deck     ' ;'skew     ';'Dc/Ds3   '];
   case 'abut_2',
T1=['L2       ';'L2/H1    ';'Dc1/Ds   ';'\rho_s,ln'; ...
    'abut     ';'skew     ';'abut/no  ';'irregular'];
   case 'abut_3',
T1=['NYI      '];
   case 'ncee_abut',
T1=['L/H (5)     ';'Dc/Ds (5)   ';'\rho_s,ln(5)'; ...
    'L/H (4)     ';'Dc/Ds (4)   ';'\rho_s,ln(4)'; ...
	'Dc/Ds (16)  '];
   case 'nsc_abut',
T1=['Ka_l 6     ';'Ka_t       ';'mass       ';'Ka_l no m 6'; ...
    'Ka_l no m 2'];
   case 'combo',
T1=['bents    '];
   otherwise
T1=['Invalid PSDA bridge type in LoadMenu'];
end;

else				% IDA
switch bridgein
   case 'no_abut_1',
T1=['L/H      ';'Dc/Ds    ';'\rho_s,ln' ;'L        ';'weight   '; ...
    'ksoil    ';'fy       ';'f''c      ';'\rho_s,tr';'abut     '; ...
	'abut/no  ';'Dc/Ds5   ';'deck     ' ;'skew     '];
   case 'no_abut_2',
T1=['NYI      '];
   case 'no_abut_3',
T1=['NYI      '];
   case 'abut_1',
T1=['NYI      '];
   case 'abut_2',
T1=['NYI      '];
   case 'abut_3',
T1=['NYI      '];
   case 'ncee_abut',
T1=['L/H (5i)      ';'Dc/Ds (5i)    ';'\rho_s,ln (5i)'; ...
    'L/H (4i)      ';'Dc/Ds (4i)    ';'\rho_s,ln (4i)'; ...
	'L/H (3i)      ';'Dc/Ds (3i)    ';'\rho_s,ln (3i)'; ...
	'L/H (4j)      ';'Dc/Ds (4j)    ';'\rho_s,ln (4j)'; ...
	'L/H (3j)      ';'Dc/Ds (3j)    ';'\rho_s,ln (3j)'; ...
	'L/H (8ij)     ';'Dc/Ds (8ij)   ';'\rho_s,ln(8ij)'];
   case 'nsc_abut',
T1=['NYI      '];
   case 'combo',
T1=['NYI      '];

   otherwise
T1=['Invalid IDA bridge type in LoadMenu'];
end;
end;

% second generate PData array corresponding to menu above
if typer == 0,		% PSDA
switch bridgein
   case 'no_abut_1',
% ------------------ LoH ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [5  6  7  8;
       			 1  2  3  4;
	             9  10 11 12;
			     13 14 15 16];
PData{1}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{1}.defs = 2.4;

% ------------------ DcDs ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [17 18 19 20;
       			 1  2  3  4;
	             21 22 23 24;
			     25 26 27 28];
PData{2}.vals = [0.67 0.75 1.00 1.30];
PData{2}.defs = 0.75;

% ------------------ rho_s ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [29 30 31 32;
       			 1  2  3  4;
	             33 34 35 36;
			     37 38 39 40];
PData{3}.vals = [0.01 0.02 0.03 0.04];
PData{3}.defs = 0.02;

% ------------------ L ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [1  2  3  4;
       			 41 42 43 44;
	             45 46 47 48;
			     49 50 51 52];
PData{4}.vals = [720 1080 1440 2160];
PData{4}.defs = 720;

% ------------------ wt ------------------
PData{5}.name = T1(5,:);
PData{5}.para = [1  2  3  4;
	             53 54 55 56;
			     57 58 59 60;
				 61 62 63 64;
				 137 138 139 140];
PData{5}.vals = [0.10 0.25 0.50 0.75 1.50];	
PData{5}.defs = 0.10;

% ------------------ ksoil ------------------
PData{6}.name = T1(6,:);
PData{6}.para = [73 74 75 76;
       			 1  2  3  4;
	             65 66 67 68;
			     69 70 71 72];
PData{6}.vals = ['A' 'B' 'C' 'D'];
PData{6}.defs = 2;

% ------------------ fy ------------------
PData{7}.name = T1(7,:);
PData{7}.para = [1  2  3  4;
       			 77 78 79 80;
	             81 82 83 84;
			     85 86 87 88];
PData{7}.vals = [65 75 85 95];	
PData{7}.defs = 65;

% ------------------ f'c ------------------
PData{8}.name = T1(8,:);
PData{8}.para = [89 90 91 92;
       			 1  2  3  4;
	             93 94 95 96;
			     97 98 99 100];
PData{8}.vals = [3 5 6 8];
PData{8}.defs = 5;

% ------------------ rho_t ------------------
PData{9}.name = T1(9,:);
PData{9}.para = [101 102 103 104;
				 105 106 107 108;
	             1   2   3   4;
			     109 110 111 112];
PData{9}.vals = [0.004 0.006 0.007 0.011];
PData{9}.defs = 0.007;

% ------------------ abut ------------------
PData{10}.name = T1(10,:);
PData{10}.para = [1   2   3   4;
				 113 114 115 116;
	             117 118 119 120;
			     121 122 123 124;
				 125 126 127 128;
				 129 130 131 132;
				 133 134 135 136];
PData{10}.vals = [0 1 2 3 4 7 8];
PData{10}.defs = -1;

% ------------------ abut/no abut ------------------
PData{11}.name = T1(11,:);
PData{11}.para = [1   2   3   4;
				 113 114 115 116;
	             117 118 119 120;
				 121 122 123 124];
PData{11}.vals = [0 1 2 3];
PData{11}.defs = -1;

% ------------------ DcDs5 ------------------
PData{12}.name = T1(12,:);
PData{12}.para = [17 18 19 20;
       			 1  2  3  4;
	             21 22 23 24;
				 141 142 143 144;
			     25 26 27 28];
PData{12}.vals = [0.67 0.75 1.00 1.15 1.30];
PData{12}.defs = -1;

% ------------------ deck ------------------
PData{13}.name = T1(13,:);
PData{13}.para = [1   2   3   4;
				 145 146 147 148];
PData{13}.vals = [0 1];
PData{13}.defs = -1;

% ------------------ skew ------------------
PData{14}.name = T1(14,:);
PData{14}.para = [1   2   3   4;
				 149 150 151 152;
	             153 154 155 156;
				 157 158 159 160];
PData{14}.vals = [0 20 40 60];
PData{14}.defs = 0;

   case 'no_abut_2',

   case 'no_abut_3',
% ------------------ L2 ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [5  6  7  8;
       			 1  2  3  4;
       			 9  10 11 12;
       			 13 14 15 16];
PData{1}.vals = [1080 1440 2160 2520];	% these must correspond to rows in .para
PData{1}.defs = 1440;

% ------------------ L2oH2 ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [17 18 19 20;
       			 21 22 23 24;
       			 1  2  3  4;
       			 25 26 27 28];
PData{2}.vals = [1.2 1.8 2.4 3.5];
PData{2}.defs = 2.4;

% ------------------ Dc2Ds ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [29 30 31 32;
       			 1  2  3  4;
       			 33 34 35 36;
       			 37 38 39 40];
PData{3}.vals = [0.67 0.80 1.0 1.3];
PData{3}.defs = 0.80;

% ------------------ irregular ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [1  2  3  4;
				 41 42 43 44;
				 45 46 47 48;
				 49 50 51 52;
				 53 54 55 56];
PData{4}.vals = [0 1 2 3 4];
PData{4}.defs = -1;

   case 'abut_1',
% ------------------ LoH ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [5  6  7  8;
       			 1  2  3  4;
	             9  10 11 12;
			     13 14 15 16];
PData{1}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{1}.defs = 2.4;

% ------------------ DcDs ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [17 18 19 20;
       			 1  2  3  4;
	             21 22 23 24;
			     25 26 27 28];
PData{2}.vals = [0.67 0.75 1.00 1.30];
PData{2}.defs = 0.75;

% ------------------ rho_s ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [29 30 31 32;
       			 1  2  3  4;
	             33 34 35 36;
			     37 38 39 40];
PData{3}.vals = [0.01 0.02 0.03 0.04];
PData{3}.defs = 0.02;

% ------------------ L ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [1  2  3  4;
       			 41 42 43 44;
	             45 46 47 48;
			     49 50 51 52];
PData{4}.vals = [720 1080 1440 2160];
PData{4}.defs = 720;

% ------------------ wt ------------------
PData{5}.name = T1(5,:);
PData{5}.para = [1  2  3  4;
	             53 54 55 56;
			     57 58 59 60;
				 61 62 63 64;
				 137 138 139 140];
PData{5}.vals = [0.10 0.25 0.50 0.75 1.50];	
PData{5}.defs = 0.10;

% ------------------ ksoil ------------------
PData{6}.name = T1(6,:);
PData{6}.para = [73 74 75 76;
       			 1  2  3  4;
	             65 66 67 68;
			     69 70 71 72];
PData{6}.vals = ['A' 'B' 'C' 'D'];	
PData{6}.defs = 2;

% ------------------ fy ------------------
PData{7}.name = T1(7,:);
PData{7}.para = [1  2  3  4;
       			 77 78 79 80;
	             81 82 83 84;
			     85 86 87 88];
PData{7}.vals = [65 75 85 95];	
PData{7}.defs = 65;

% ------------------ f'c ------------------
PData{8}.name = T1(8,:);
PData{8}.para = [89 90 91 92;
       			 1  2  3  4;
	             93 94 95 96;
			     97 98 99 100];
PData{8}.vals = [3 5 6 8];	
PData{8}.defs = 5;

% ------------------ rho_t ------------------
PData{9}.name = T1(9,:);
PData{9}.para = [101 102 103 104;
				 105 106 107 108;
	             1   2   3   4;
			     109 110 111 112];
PData{9}.vals = [0.004 0.006 0.007 0.011];
PData{9}.defs = 0.007;

% ------------------ DcDs5 ------------------
PData{10}.name = T1(10,:);
PData{10}.para = [17 18 19 20;
       			 1  2  3  4;
	             21 22 23 24;
				 141 142 143 144;
			     25 26 27 28];
PData{10}.vals = [0.67 0.75 1.00 1.15 1.30];
PData{10}.defs = -1;

% ------------------ deck ------------------
PData{11}.name = T1(11,:);
PData{11}.para = [1   2   3   4;
				 145 146 147 148];
PData{11}.vals = [0 1];
PData{11}.defs = -1;

% ------------------ skew ------------------
PData{12}.name = T1(12,:);
PData{12}.para = [1   2   3   4;
				 149 150 151 152;
	             153 154 155 156;
				 157 158 159 160];
PData{12}.vals = [0 20 40 60];
PData{12}.defs = 0;

% ------------------ DcDs3 ------------------
PData{13}.name = T1(13,:);
PData{13}.para = [1  2  3  4;
	             21 22 23 24;
			     25 26 27 28];
PData{13}.vals = [0.75 1.00 1.30];
PData{13}.defs = -1;

   case 'abut_2',
% ------------------ L2 ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [5  6  7  8;
       			 1  2  3  4;
	             9  10 11 12;
			     13 14 15 16];
PData{1}.vals = [1080 1440 2160 2520];	% these must correspond to rows in .para
PData{1}.defs = 1440;

% ------------------ L2oH1 ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [17 18 19 20;
       			 21 22 23 24;
				 1  2  3  4;
			     25 26 27 28];
PData{2}.vals = [1.2 1.8 2.4 3.5];
PData{2}.defs = 2.4;

% ------------------ Dc1Ds ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [29 30 31 32;
		 	     1  2  3  4;
	             33 34 35 36;
				 37 38 39 40];
PData{3}.vals = [0.67 0.80 1.00 1.30];
PData{3}.defs = 0.80;

% ------------------ rho_s ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [41 42 43 44;
				 1  2  3  4;
	             45 46 47 48;
			     49 50 51 52];
PData{4}.vals = [0.01 0.02 0.03 0.04];
PData{4}.defs = 0.02;

% ------------------ abut ------------------
PData{5}.name = T1(5,:);
PData{5}.para = [53 54 55 56;
       			 57 58 59 60;
       			 1  2  3  4;
       			 61 62 63 64;
       			 65 66 67 68;
       			 69 70 71 72;
       			 73 74 75 76];
PData{5}.vals = [0 1 2 3 4 7 8];
PData{5}.defs = -1;

% ------------------ skew ------------------
PData{6}.name = T1(6,:);
PData{6}.para = [1  2  3  4;
       			 77 78 79 80;
       			 81 82 83 84;
       			 85 86 87 88];
PData{6}.vals = [0 20 40 60];
PData{6}.defs = 0;

% ------------------ abut/no abut ------------------
PData{7}.name = T1(7,:);
PData{7}.para = [53 54 55 56;
       			 57 58 59 60;
       			 1  2  3  4;
       			 61 62 63 64];
PData{7}.vals = [0 1 2 3];
PData{7}.defs = -1;

% ------------------ irregular ------------------
PData{8}.name = T1(8,:);
PData{8}.para = [1  2  3  4;
				 89 90 91 92;
				 93 94 95 96];
PData{8}.vals = [0 1 2];
PData{8}.defs = -1;

   case 'abut_3',
   
   case 'ncee_abut',
   % ------------------ LoH 5 ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [6  7  8  9  10;
       			 1  2  3  4  5;
	             11 12 13 14 15;
			     16 17 18 19 20];
PData{1}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{1}.defs = -1;

% ------------------ DcDs 5 ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [21 22 23 24 25;
       			 1  2  3  4  5;
	             26 27 28 29 30;
			     31 32 33 34 35];
PData{2}.vals = [0.67 0.75 1.00 1.30];
PData{2}.defs = -1;

% ------------------ rho_s 5 ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [36 37 38 39 40;
       			 1  2  3  4  5;
	             41 42 43 44 45;
			     46 47 48 49 50];
PData{3}.vals = [0.01 0.02 0.03 0.04];
PData{3}.defs = -1;

% ------------------ LoH 4 ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [6  7  8  9;
       			 1  2  3  4;
	             11 12 13 14;
			     16 17 18 19];
PData{4}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{4}.defs = 2.4;

% ------------------ DcDs 4 ------------------
PData{5}.name = T1(5,:);
PData{5}.para = [21 22 23 24;
       			 1  2  3  4;
	             26 27 28 29;
			     31 32 33 34];
PData{5}.vals = [0.67 0.75 1.00 1.30];
PData{5}.defs = 0.75;

% ------------------ rho_s 4 ------------------
PData{6}.name = T1(6,:);
PData{6}.para = [36 37 38 39;
       			 1  2  3  4;
	             41 42 43 44;
			     46 47 48 49];
PData{6}.vals = [0.01 0.02 0.03 0.04];
PData{6}.defs = 0.02;

% ------------------ DcDs 16 ------------------
PData{7}.name = T1(7,:);
PData{7}.para = [21 22 23 24 63 64 65 66 67 68 69 70 71 72 73 74;
       			 1  2  3  4  51 52 53 54 55 56 57 58 59 60 61 62;
	             26 27 28 29 75 76 77 78 79 80 81 82 83 84 85 86;
			     31 32 33 34 87 88 89 90 91 92 93 94 95 96 97 98];
PData{7}.vals = [0.67 0.75 1.00 1.30];
PData{7}.defs = -1;

   case 'nsc_abut',
% ------------------ Ka,l ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [1  2  3  4;
			     5  6  7  8;
	             9  10 11 12;
			     13 14 15 16;
				 17 18 19 20];
PData{1}.vals = [0 250 500 750 1000];	% these must correspond to rows in .para
PData{1}.defs = 0;

% ------------------ Ka,t ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [1  2  3  4;
			     21 22 23 24;
       			 9  10 11 12;
	             25 26 27 28;
			     29 30 31 32];
PData{2}.vals = [0 250 500 750 1000];
PData{2}.defs = 0;

% ------------------ mass ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [1  2  3  4;
			     33 34 35 36;
       			 9  10 11 12;
	             37 38 39 40;
			     41 42 43 44];
PData{3}.vals = [0 2 4 6 8];
PData{3}.defs = 0;

% ------------------ Ka,l no mass 6.0 gap ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [1  2  3  4;
			     45 46 47 48;
	             49 50 51 52;
			     53 54 55 56;
				 57 58 59 60];
PData{4}.vals = [0 250 500 750 1000];
PData{4}.defs = -1;

% ------------------ Ka,l no mass 2.0 gap ------------------
PData{5}.name = T1(5,:);
PData{5}.para = [1  2  3  4;
				 65 66 67 68;
			     61 62 63 64;
				 69 70 71 72;
				 73 74 75 76];
PData{5}.vals = [0 250 500 750 1000];
PData{5}.defs = -1;

   case 'combo',
% ------------------ bents ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [1  2  3  4;
				 5  6  7  8
	             9  10 11 12];
PData{1}.vals = [1 2 3];		% these must correspond to rows in .para
PData{1}.defs = -1;

   otherwise
PData=['Invalid PSDA bridge type in LoadMenu'];
end;
else				% IDA
switch bridgein
   case 'no_abut_1',
% ------------------ LoH ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [5  6  7  8;
       			 1  2  3  4;
	             9  10 11 12;
			     13 14 15 16];
PData{1}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{1}.defs = 2.4;

% ------------------ DcDs ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [17 18 19 20;
       			 1  2  3  4;
	             21 22 23 24;
			     25 26 27 28];
PData{2}.vals = [0.67 0.75 1.00 1.30];
PData{2}.defs = 0.75;

% ------------------ rho_s ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [29 30 31 32;
       			 1  2  3  4;
	             33 34 35 36;
			     37 38 39 40];
PData{3}.vals = [0.01 0.02 0.03 0.04];
PData{3}.defs = 0.02;

% ------------------ L ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [1  2  3  4;
       			 41 42 43 44;
	             45 46 47 48;
			     49 50 51 52];
PData{4}.vals = [720 1080 1440 2160];
PData{4}.defs = 720;

% ------------------ wt ------------------
PData{5}.name = T1(5,:);
PData{5}.para = [1  2  3  4;
	             53 54 55 56;
			     57 58 59 60;
				 61 62 63 64;
				 137 138 139 140];
PData{5}.vals = [0.10 0.25 0.50 0.75 1.50];	
PData{5}.defs = 0.10;

% ------------------ ksoil ------------------
PData{6}.name = T1(6,:);
PData{6}.para = [73 74 75 76;
       			 1  2  3  4;
	             65 66 67 68;
			     69 70 71 72];
PData{6}.vals = ['A' 'B' 'C' 'D'];	
PData{6}.defs = 2;

% ------------------ fy ------------------
PData{7}.name = T1(7,:);
PData{7}.para = [1  2  3  4;
       			 77 78 79 80;
	             81 82 83 84;
			     85 86 87 88];
PData{7}.vals = [65 75 85 95];	
PData{7}.defs = 65;

% ------------------ f'c ------------------
PData{8}.name = T1(8,:);
PData{8}.para = [89 90 91 92;
       			 1  2  3  4;
	             93 94 95 96;
			     97 98 99 100];
PData{8}.vals = [3 5 6 8];	
PData{8}.defs = 5;

% ------------------ rho_t ------------------
PData{9}.name = T1(9,:);
PData{9}.para = [101 102 103 104;
				 105 106 107 108;
	             1   2   3   4;
			     109 110 111 112];
PData{9}.vals = [0.004 0.006 0.007 0.011];
PData{9}.defs = 0.007;

% ------------------ abut ------------------
PData{10}.name = T1(10,:);
PData{10}.para = [1   2   3   4;
				 113 114 115 116;
	             117 118 119 120;
			     121 122 123 124;
				 125 126 127 128;
				 129 130 131 132;
				 133 134 135 136];
PData{10}.vals = [0 1 2 3 4 7 8];
PData{10}.defs = -1;

% ------------------ abut/no abut ------------------
PData{11}.name = T1(11,:);
PData{11}.para = [1   2   3   4;
				 113 114 115 116;
	             117 118 119 120;
				 121 122 123 124];
PData{11}.vals = [0 1 2 3];
PData{11}.defs = -1;

% ------------------ DcDs5 ------------------
PData{12}.name = T1(12,:);
PData{12}.para = [17 18 19 20;
       			 1  2  3  4;
	             21 22 23 24;
				 141 142 143 144;
			     25 26 27 28];
PData{12}.vals = [0.67 0.75 1.00 1.15 1.30];
PData{12}.defs = -1;

% ------------------ deck ------------------
PData{13}.name = T1(13,:);
PData{13}.para = [1   2   3   4;
				 145 146 147 148];
PData{13}.vals = [0 1];
PData{13}.defs = -1;

% ------------------ skew ------------------
PData{14}.name = T1(14,:);
PData{14}.para = [1   2   3   4;
				 149 150 151 152;
	             153 154 155 156;
				 157 158 159 160];
PData{14}.vals = [0 20 40 60];
PData{14}.defs = 0;

   case 'no_abut_2',

   case 'no_abut_3',

   case 'abut_1',

   case 'abut_2',

   case 'abut_3',
   
   case 'ncee_abut',
% ------------------ LoH5i ------------------
PData{1}.name = T1(1,:);
PData{1}.para = [6  7  8  9  10;
       			 1  2  3  4  5;
	             11 12 13 14 15;
			     16 17 18 19 20];
PData{1}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{1}.defs = -1;

% ------------------ DcDs5i ------------------
PData{2}.name = T1(2,:);
PData{2}.para = [21 22 23 24 25;
       			 1  2  3  4  5;
	             26 27 28 29 30;
			     31 32 33 34 35];
PData{2}.vals = [0.67 0.75 1.00 1.30];
PData{2}.defs = -1;

% ------------------ rho_s5i ------------------
PData{3}.name = T1(3,:);
PData{3}.para = [36 37 38 39 40;
       			 1  2  3  4  5;
	             41 42 43 44 45;
			     46 47 48 49 50];
PData{3}.vals = [0.01 0.02 0.03 0.04];
PData{3}.defs = -1;

% ------------------ LoH4i ------------------
PData{4}.name = T1(4,:);
PData{4}.para = [6  7  8  9;
       			 1  2  3  4;
	             11 12 13 14;
			     16 17 18 19];
PData{4}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{4}.defs = -1;

% ------------------ DcDs4i ------------------
PData{5}.name = T1(5,:);
PData{5}.para = [21 22 23 24;
       			 1  2  3  4;
	             26 27 28 29;
			     31 32 33 34];
PData{5}.vals = [0.67 0.75 1.00 1.30];
PData{5}.defs = -1;

% ------------------ rho_s4i ------------------
PData{6}.name = T1(6,:);
PData{6}.para = [36 37 38 39;
       			 1  2  3  4;
	             41 42 43 44;
			     46 47 48 49];
PData{6}.vals = [0.01 0.02 0.03 0.04];
PData{6}.defs = -1;

% ------------------ LoH3i ------------------
PData{7}.name = T1(7,:);
PData{7}.para = [7  8  9;
       			 2  3  4;
	             12 13 14;
			     17 18 19];
PData{7}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{7}.defs = -1;

% ------------------ DcDs3i ------------------
PData{8}.name = T1(8,:);
PData{8}.para = [22 23 24;
       			 2  3  4;
	             27 28 29;
			     32 33 34];
PData{8}.vals = [0.67 0.75 1.00 1.30];
PData{8}.defs = -1;

% ------------------ rho_s3i ------------------
PData{9}.name = T1(9,:);
PData{9}.para = [37 38 39;
       			 2  3  4;
	             42 43 44;
			     47 48 49];
PData{9}.vals = [0.01 0.02 0.03 0.04];
PData{9}.defs = -1;

% ------------------ LoH4j ------------------
PData{10}.name = T1(10,:);
PData{10}.para = [55 56 57 58;
       			 51 52 53 54;
	             59 60 61 62;
			     63 64 65 66];
PData{10}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{10}.defs = -1;

% ------------------ DcDs4j ------------------
PData{11}.name = T1(11,:);
PData{11}.para = [67 68 69 70;
       			 51 52 53 54;
	             71 72 73 74;
			     75 76 77 78];
PData{11}.vals = [0.67 0.75 1.00 1.30];
PData{11}.defs = -1;

% ------------------ rho_s4j ------------------
PData{12}.name = T1(12,:);
PData{12}.para = [79 80 81 82;
       			 51 52 53 54;
	             83 84 85 86;
			     87 88 89 90];
PData{12}.vals = [0.01 0.02 0.03 0.04];
PData{12}.defs = -1;

% ------------------ LoH3j ------------------
PData{13}.name = T1(13,:);
PData{13}.para = [56 57 58;
       			 52 53 54;
	             60 61 62;
			     64 65 66];
PData{13}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{13}.defs = -1;

% ------------------ DcDs3j ------------------
PData{14}.name = T1(14,:);
PData{14}.para = [68 69 70;
       			 52 53 54;
	             72 73 74;
			     76 77 78];
PData{14}.vals = [0.67 0.75 1.00 1.30];
PData{14}.defs = -1;

% ------------------ rho_s3j ------------------
PData{15}.name = T1(15,:);
PData{15}.para = [80 81 82;
       			 52 53 54;
	             84 85 86;
			     88 89 90];
PData{15}.vals = [0.01 0.02 0.03 0.04];
PData{15}.defs = -1;

% ------------------ LoH8ij ------------------
PData{16}.name = T1(16,:);
PData{16}.para = [6  7  8  9 55 56 57 58;
       			  1  2  3  4 51 52 53 54;
	             11 12 13 14 59 60 61 62;
			     16 17 18 19 63 64 65 66];
PData{16}.vals = [3.5 2.4 1.8 1.2];		% these must correspond to rows in .para
PData{16}.defs = 2.4;

% ------------------ DcDs8ij ------------------
PData{17}.name = T1(17,:);
PData{17}.para = [21 22 23 24 67 68 69 70;
       			  1  2  3  4  51 52 53 54;
	              26 27 28 29 71 72 73 74;
			      31 32 33 34 75 76 77 78];
PData{17}.vals = [0.67 0.75 1.00 1.30];
PData{17}.defs = 0.75;

% ------------------ rho_s8ij ------------------
PData{18}.name = T1(18,:);
PData{18}.para = [36 37 38 39 79 80 81 82;
       			  1  2  3  4  51 52 53 54;
	              41 42 43 44 83 84 85 86;
			      46 47 48 49 87 88 89 90];
PData{18}.vals = [0.01 0.02 0.03 0.04];
PData{18}.defs = 0.02;

   otherwise
PData=['Invalid IDA bridge type in LoadMenu'];
end;
end;
