function [NAME_VALUES,IM,DM,RS] = LoadVals(bridgein)
%[NAME_VALUES,IM,DM]=LoadVals Load output file information provider
%   Kevin Mackie, 2002/01/26
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   bridgein name of bridge type to associate values and names
%
%   NAME_VALUES is the name associate with linenum in the summary file
%   suffixed by the type of data 0=IM, 1=DM, 2=do not include
%   IM matrix relating global line numbers to only those with IM values
%   DM matrix relating global line numbers to only those with DM values
%
% Note: This file must be updated based on the order of data written to
% the outputs files for any given set of runs.  These values must all have
% the same length description, suffixed by the type of data is represents
% (see above).  

switch bridgein
   case 'no_abut_1',
      NAME_VALUES=bent_1;
   case 'no_abut_2',
      NAME_VALUES=bent_2;
   case 'no_abut_3',
      NAME_VALUES=bent_3;
   case 'abut_1',
      NAME_VALUES=bent_1;
   case 'abut_2',
      NAME_VALUES=bent_2;
   case 'abut_3',
      NAME_VALUES=bent_3;
   case 'ncee_abut',
      NAME_VALUES=bent_1;
   case 'nsc_abut',
      NAME_VALUES=bent_1;
   case 'combo',
      NAME_VALUES=bent_1;
   otherwise
      bstring='Invalid bridge type in LoadVals';
end;

% Extract a list of values which are specifically
% either DM (1) or IM (0)
% Note then that type (2) cannot be plotted and are
% for information only, add them to (0) or (1)
% if desired for plotting
% Note that Duration, Magnitude and Distance (in that order)
% are denoted (3) but are also added to the IMs, but the last
% value (T) is also a (3) but not useful as an IM
[m,n]=size(NAME_VALUES);
len=length(NAME_VALUES(1,:));
imcnt=1;
dmcnt=1;
rscnt=1;
for k=1:m,
   tailval=str2num(NAME_VALUES(k,len));
   if tailval==0,
      IM(imcnt,1:2)=[imcnt,k];
	  imcnt=imcnt+1;
   elseif tailval==1,
      DM(dmcnt,1:2)=[dmcnt,k];
	  dmcnt=dmcnt+1;
   elseif tailval==3,
      RS(rscnt,1:2)=[rscnt,k];
	  rscnt=rscnt+1;
	  if rscnt <= 4        % this excludes T information from IM array
	     IM(imcnt,1:2)=[imcnt,k];
	     imcnt=imcnt+1;
	  end;
   end;
end;

NAME_VALUES=NAME_VALUES(:,1:len-1);
