function PlotIDA(grp,EQ,DATA,xname,yname)
%PlotIDA(grp,DATA,xname,yname,fit) Plots IDA
%   Kevin Mackie, 2001/08/17
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: grp (Ax2) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM) 
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots the IM DM relationship in IDA form for each EQ

[m,n]=size(grp);
TEQ=20;       % total number of earthquakes per bin

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

clrs='brmgckybrmgck';
lins='ox+^*sdv<>ph.';

Lcs=['brmgcky'];
Lts=['- ';
     '-.';
	 '--';
	 ': ';
	 's ';
	 'p ';
	 'h '];

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

for bins=0:EQ-1,
   for k=1:n,
      newgrp{k}.v(1:TEQ,:)=grp{k}.v(1+TEQ*bins:TEQ+TEQ*bins,:);
   end

   if bins==1,
      hold on;
   end;
   
   logplot='H=plot(';
   legplot='legend(';
   for k=1:n,
      logplot=sprintf('%snewgrp{%i}.v(:,1),newgrp{%i}.v(:,2),[Lcs(%i),Lts(%i+1,:)]',logplot,k,k,k,bins);
      legplot=sprintf('%sstrcat(DATA.name,''='',num2str(DATA.vals(%i)))',legplot,k);
      if k<n,
         logplot=sprintf('%s, ',logplot);
    	 legplot=sprintf('%s, ',legplot);
      end;
   end

   logplot=sprintf('%s);',logplot);
   legplot=sprintf('%s,4);',legplot);

   eval(logplot);
end;

hold off;

titplot='title(strcat(''Intensity Measure vs Demand Measure (IDA) - '',';
for k=1:EQ,
   titplot=sprintf('%s'' Eq '',num2str(%i),''('',Lts(%i,:),'')''',titplot,k,k);
   if k<EQ,
      titplot=sprintf('%s,'','', ',titplot);
   end;
end;
titplot=sprintf('%s));',titplot);

axis tight;
set(H,'MarkerSize',4);
grid on;
xlabel(xname);
ylabel(yname);
eval(titplot);
eval(legplot);
set(HH,'Tag','Axes1');
