function PlotSeismParam(grp,EQ,DATA,xname,yname)
%PlotSeismParam(grp,DATA,xname,yname) Plots bin dependence
%   Kevin Mackie, 2001/07/19
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: grp (Ax2) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM)
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots 16 lines, one for each parameter and bin.  Parameters have the same color, bins
% have the same line type.  Plot title gives the line types per bin
% LMSR is -  LMLR is -.  SMSR is --  SMLR ..
% To avoid dependence of performance on the different bins, lines of the same color 
% should have the same (or similar) slope.
% (NOTE: better plot might be of the slope, not of all the lines)

[m,n]=size(grp);
TEQ=20;       % total number of earthquakes per bin

Lcs=['brmgcky'];
Lts=['- ';
     '-.';
	 '--';
	 ': ';
	 's ';
	 'p ';
	 'h '];

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

for bins=0:EQ-1,
   for k=1:n,
      newgrp{k}.v(1:TEQ,:)=grp{k}.v(1+TEQ*bins:TEQ+TEQ*bins,:);
   end
  
   [xylog,linexlog,lineylog,Fits,Dispersion]=FitData(newgrp,1,EQ);
   if bins==1,
      hold on;
   end;
   
   logplot='H=plot(';
   legplot='legend(';
   for k=1:n,
      logplot=sprintf('%slinexlog{%i},lineylog{%i},[Lcs(%i),Lts(%i+1,:)]',logplot,k,k,k,bins);
      legplot=sprintf('%sstrcat(DATA.name,''='',num2str(DATA.vals(%i)))',legplot,k);
      if k<n,
         logplot=sprintf('%s, ',logplot);
    	 legplot=sprintf('%s, ',legplot);
      end;
   end

   logplot=sprintf('%s);',logplot);
   legplot=sprintf('%s,4);',legplot);

   eval(logplot);
   
   Slopes(bins+1,:)=Fits(:,1)';
end;

hold off;
set(gca,'Xscale','log');
set(gca,'Yscale','log');
axis tight;
eval(legplot);
grid on;
xlabel(xname);
ylabel(yname);
title('Bin dependence (LMSR -) (LMLR -.) (SMSR --) (SMLR..)');
set(HH,'Tag','Axes1');

% at the moment this just pops up another window with the slopes
% make this more elegant in the future
Slopes
figure(11);
plot([1:1:EQ],Slopes);
title('Slope variation - hit any key to continue');
xlabel('Bin number');
ylabel('Slope');
grid;
eval(legplot);
pause;
close(11);
